Adam Litke has uploaded a new change for review.
Change subject: schema: Missing comment for new VmDeviceType
......................................................................
schema: Missing comment for new VmDeviceType
When adding a new 'console' VmDeviceType, the submitter forgot to include
documentation in the comment block. This caused process-schema.py to fail.
Change-Id: Icd7db71a4cd1a2addd31815a73dcd5c1cda7af4f
Signed-off-by: Adam Litke <agl(a)us.ibm.com>
---
M vdsm_api/vdsmapi-schema.json
1 file changed, 2 insertions(+), 0 deletions(-)
git pull ssh://gerrit.ovirt.org:29418/vdsm refs/changes/13/10013/1
diff --git a/vdsm_api/vdsmapi-schema.json b/vdsm_api/vdsmapi-schema.json
index cf02f31..1b1c075 100644
--- a/vdsm_api/vdsmapi-schema.json
+++ b/vdsm_api/vdsmapi-schema.json
@@ -1681,6 +1681,8 @@
#
# @channel: A host-guest communication channel
#
+# @console: A console device
+#
# Since: 4.10.0
##
{'enum': 'VmDeviceType',
--
To view, visit http://gerrit.ovirt.org/10013
To unsubscribe, visit http://gerrit.ovirt.org/settings
Gerrit-MessageType: newchange
Gerrit-Change-Id: Icd7db71a4cd1a2addd31815a73dcd5c1cda7af4f
Gerrit-PatchSet: 1
Gerrit-Project: vdsm
Gerrit-Branch: master
Gerrit-Owner: Adam Litke <agl(a)us.ibm.com>
Adam Litke has uploaded a new change for review.
Change subject: schema: Fix schema for VM.updateDevice
......................................................................
schema: Fix schema for VM.updateDevice
Another recent update broke the schema file. I'll take the blame for this one
since I approved the change :) Some missing and/or malformed data in comments
was causing the process-schema script to fail. Another reason for validating
the schema during the build.
Change-Id: If88596050ace9511bcc7be65ee46645359e30532
Signed-off-by: Adam Litke <agl(a)us.ibm.com>
---
M vdsm_api/vdsmapi-schema.json
1 file changed, 5 insertions(+), 4 deletions(-)
git pull ssh://gerrit.ovirt.org:29418/vdsm refs/changes/12/10012/1
diff --git a/vdsm_api/vdsmapi-schema.json b/vdsm_api/vdsmapi-schema.json
index bd15cbb..cf02f31 100644
--- a/vdsm_api/vdsmapi-schema.json
+++ b/vdsm_api/vdsmapi-schema.json
@@ -4909,10 +4909,12 @@
##
# @vmUpdateDeviceParams:
#
+# A discriminated record of update parameters for a VM device.
+#
# @deviceType: The VM device type to update. For example 'interface' for
# network devices or 'disk' for disk storage devices.
#
-# Since 4.10.3
+# Since: 4.10.3
##
{'type': 'vmUpdateDeviceParams',
'data': {'deviceType': 'VmDeviceType'},
@@ -4939,11 +4941,11 @@
# by alias. If omitted, it keeps the current mirroring
# configuration.
#
-# Since 4.10.3
+# Since: 4.10.3
##
{'type': 'vmUpdateInterfaceDeviceParams',
'data': {'*network': 'str', '*linkActive': 'bool',
- 'alias': 'str', '*portMirroring': '[str]'}}
+ 'alias': 'str', '*portMirroring': ['str']}}
##
# @VM.updateDevice:
@@ -4958,7 +4960,6 @@
# The VM definition, as updated
#
# Since: 4.10.3
-#
##
{'command': {'class': 'VM', 'name': 'updateDevice'},
'data': {'vmId': 'UUID', 'params': 'vmUpdateDeviceParams'},
--
To view, visit http://gerrit.ovirt.org/10012
To unsubscribe, visit http://gerrit.ovirt.org/settings
Gerrit-MessageType: newchange
Gerrit-Change-Id: If88596050ace9511bcc7be65ee46645359e30532
Gerrit-PatchSet: 1
Gerrit-Project: vdsm
Gerrit-Branch: master
Gerrit-Owner: Adam Litke <agl(a)us.ibm.com>
Adam Litke has uploaded a new change for review.
Change subject: schema: Missing schema information for 'syncType'
......................................................................
schema: Missing schema information for 'syncType'
Commit <> added a new API Image.syncData but did not fully spec the arguments.
The referenced enum type 'syncData' has no definition. Adding the missing bit
based on my examination of the code.
This is why we need something like http://gerrit.ovirt.org/#/c/9433/ to validate
the schema at build time.
Change-Id: Ib2c5df5d39e9bb184958b32449d671f74c3af494
Signed-off-by: Adam Litke <agl(a)us.ibm.com>
---
M vdsm_api/vdsmapi-schema.json
1 file changed, 15 insertions(+), 0 deletions(-)
git pull ssh://gerrit.ovirt.org:29418/vdsm refs/changes/11/10011/1
diff --git a/vdsm_api/vdsmapi-schema.json b/vdsm_api/vdsmapi-schema.json
index 9772e18..bd15cbb 100644
--- a/vdsm_api/vdsmapi-schema.json
+++ b/vdsm_api/vdsmapi-schema.json
@@ -3065,6 +3065,21 @@
'returns': 'UUID'}
##
+# @syncType:
+#
+# An enumeration of possible Image synchronization types.
+#
+# @ALL: Sync all volumes
+#
+# @INTERNAL: Sync internal volumes only
+#
+# @LEAF: Sync leaf volumes only
+#
+# Since: 4.11.0
+##
+{'enum': 'syncType', 'data': ['ALL', 'INTERNAL', 'LEAF']}
+
+##
# @Image.syncData:
#
# Synchronize image data between storage domains within same Storage Pool.
--
To view, visit http://gerrit.ovirt.org/10011
To unsubscribe, visit http://gerrit.ovirt.org/settings
Gerrit-MessageType: newchange
Gerrit-Change-Id: Ib2c5df5d39e9bb184958b32449d671f74c3af494
Gerrit-PatchSet: 1
Gerrit-Project: vdsm
Gerrit-Branch: master
Gerrit-Owner: Adam Litke <agl(a)us.ibm.com>
Mark Wu has uploaded a new change for review.
Change subject: Fix duplicate emulated machines returned
......................................................................
Fix duplicate emulated machines returned
The old code use getElementsByTagName('machine') to collect machines
information, which will hit the default info for that arch and the
kvm domain's. This patch changes to collect machines information from
the node of kvm domain.
Change-Id: I7e28688bf09b5bc413afffe9cc1501d4247d67e0
Signed-off-by: Mark Wu <wudxw(a)linux.vnet.ibm.com>
---
M vdsm/caps.py
1 file changed, 6 insertions(+), 6 deletions(-)
git pull ssh://gerrit.ovirt.org:29418/vdsm refs/changes/08/8208/1
diff --git a/vdsm/caps.py b/vdsm/caps.py
index 98b33ab..c00c957 100644
--- a/vdsm/caps.py
+++ b/vdsm/caps.py
@@ -98,15 +98,15 @@
def _getEmulatedMachines():
c = libvirtconnection.get()
caps = minidom.parseString(c.getCapabilities())
- guestTag = caps.getElementsByTagName('guest')
- # Guest element is missing if kvm modules are not loaded
- if len(guestTag) == 0:
+ for domainNode in caps.getElementsByTagName('domain'):
+ if domainNode.getAttribute('type') == 'kvm':
+ break
+ else:
+ # KVM domain is missing if kvm modules are not loaded
return []
- guestTag = guestTag[0]
-
return [m.firstChild.toxml()
- for m in guestTag.getElementsByTagName('machine')]
+ for m in domainNode.getElementsByTagName('machine')]
def _getAllCpuModels():
--
To view, visit http://gerrit.ovirt.org/8208
To unsubscribe, visit http://gerrit.ovirt.org/settings
Gerrit-MessageType: newchange
Gerrit-Change-Id: I7e28688bf09b5bc413afffe9cc1501d4247d67e0
Gerrit-PatchSet: 1
Gerrit-Project: vdsm
Gerrit-Branch: master
Gerrit-Owner: Mark Wu <wudxw(a)linux.vnet.ibm.com>